.. role:: hidden
    :class: hidden-section

gpytorch.metrics
===================================

.. automodule:: gpytorch.metrics
.. currentmodule:: gpytorch.metrics

See `the metrics tutorial`_ for usage instructions.

.. automethod:: gpytorch.metrics.mean_absolute_error
.. automethod:: gpytorch.metrics.mean_squared_error
.. automethod:: gpytorch.metrics.mean_standardized_log_loss
.. automethod:: gpytorch.metrics.negative_log_predictive_density
.. automethod:: gpytorch.metrics.quantile_coverage_error

.. _the metrics tutorial:
    examples/00_Basic_Usage/Metrics.html
